Description Usage Format Details
Sullivan Statistics Survey I data
1 |
The variables are
Gender: The gender of the respondent.
Age: The age of the respondent (in years).
Birth: The birth month of the respondent.
Text: In the past week, have you texted while driving?
Language: Is a language other than English the primary language spoken in your home?
TV: How many televisions are in your home?
Smoke: Do you currently smoke?
Party: What best describes your political affiliation?
Philosophy: What best describes your political philosophy?
Hour_Internet: How many hours did you spend on the Internet last week (Sunday through Saturday)?
Hour_TV: How many hours did you watch television last week (Sunday through Saturday)?
Rich: In your opinion, whta minimum annual income for an individual qualifies as an individual to be considered rich?
Deficit: Would you be willing to pay higher taxes if the tax revenue went directly toward deficit reduction?
Tickets: How many speeding tickets have you been issued in the past 12 months?
Children: What do you think is the ideal number of children for a family to have?
Height: What is your height (in inches)?
Foot: What is the length of your foot (in inches)?
Job: Do you currently have a job?
Hour_Work: If yes, how many hours did you work last week (Sunday through Saturday)?
Credit: Do you currently have any credit cards?
Cards: If yes, how many credit cards do you have?
Debt: if yes, to the nearest dollar, what is the total outstanding balance on your credit cards?
@keywords datasets
@source StatCrunch Survey
This data represents the results of a survey written by the students of Michael Sullivan.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.